[windowheader]
<table align="center" border="0" id="window[id/]" [hidden/] cellpadding="0" cellspacing="0" summary="thread"  class="[class/]"><tr align="left" id="tr[id/]" [hidden/]  style="cursor:pointer"><td align="left" width="5"><img alt="" src="/style/[style/]/window/wlobg.png" width="5"  border="0"/></td><td align="left" style="background-image:url('/style/[style/]/window/wdcobg.png'); background-repeat:repeat-x;"><table border="0" cellpadding="0" cellspacing="0" summary="layoutTitle" width="100%"><tr align="left" ><td onmousedown="startdrag('window[id/]');" style="font-size:14px;width:100px;" width="170"><a name="[id/]"></a>[title/]</td><td onmousedown="startdrag('window[id/]');" align="right" valign="middle" width="80">[menu/]</td></tr></table></td><td width="5"><img src="/style/[style/]/window/wrobg.png" alt="" width="5" height="26"  border="0" /></td></tr><tr align="left"  id="messageBody[id/]"><td width="5" align="left" style=" background-position:left;background-image:url('/style/[style/]/window/wlbg.png'); background-repeat:repeat-y;"></td><td align="left"  style=" background-image:url('/style/[style/]/window/background.png');">
[/windowheader]
[windowfooter]
</td><td width="5" align="left" style=" background-position:left;background-image:url('/style/[style/]/window/wrbg.png');background-repeat:repeat-y;"></td></tr><tr align="left"><td  width="5"><img src="/style/[style/]/window/wlubg.png" alt="" width="5" height="2" border="0"/></td><td style=" background-image:url('/style/[style/]/window/wdcubg.png'); background-repeat:repeat-x;"></td><td><img src="/style/[style/]/window/wrubg.png" alt="" width="5" height="2" border="0"/></td></tr>
</table>
[/windowfooter]
